## LinkedIn posts about The Cyber Boardroom

This page features recent LinkedIn posts about The Cyber Boardroom, highlighting our latest updates and announcements. From product launches and company milestones to interviews and insights, these posts keep you informed about our journey and developments. Explore the updates below to discover more about our progress and future plans
 
- 31/July/2024 - [Qroq support and GenAI speak in 6x languages](https://www.linkedin.com/pulse/qroq-support-genai-speak-6x-languages-dinis-cruz-bw8tf)
- July 30, 2024 - [Introducing the Community edition of The Cyber Boardroom](https://www.linkedin.com/pulse/introducing-community-edition-cyber-boardroom-dinis-cruz-xsope)
 - 16/Jul/2024 - [The Cyber Boardroom: Why, How, and What (v0.4 - First MVP)](https://www.linkedin.com/pulse/cyber-boardroom-why-how-what-v04-first-mvp-dinis-cruz-pbfge)
 - July 10, 2024 - [Interview: Dinis Cruz on The Cyber Boardoom](https://www.linkedin.com/pulse/interview-dinis-cruz-cyber-boardoom-dinis-cruz-nmmue)
- April 8, 2024 - [The Cyber Boardroom LTD has been created, it's official now :) ](https://www.linkedin.com/pulse/cyber-boardroom-ltd-has-been-created-its-official-now-dinis-cruz-oaj8e)